## What is it?
**sammhelper** is a Python package that supports mathematical modeling in the field of urban water management. It provides all functions required in the ETH Zurich lecture [Systems Analysis and Mathematical Modeling in Urban Water Management](https://sww.ifu.ethz.ch/education/lectures/systems-analysis.html).

## Main Features
**sammhelper** provides wrapper functions for:
- Ideal reactors modeling
- Sensitivity functions
- Parameter identification
- Error propagation
- Monte Carlo simulation
- PID controller

## Where to get it
The source code is currently hosted on ... (**TBD**).
The binary installer for the latest released version is available at the Python Package Index (PyPI):
```
pip install sammhelper
```

## Dependencies
- [Numpy](https://numpy.org/)
- [Scipy](https://scipy.org/)
- ...

## Documentation
The official documentation is hosted on ...

## Background
Work on **sammhelper** started at the [Chairs of Urban Water Management](https://sww.ifu.ethz.ch/) (ETH Zurich) in 2021 and has been under active development since then.

## Getting Help
<sww@ifu.baug.ethz.ch>